@@ -41,10 +41,10 @@ coxmeTable <- function(mod) {
 #' fit <- coxme(Surv(time, status) ~ ph.ecog + age + (1 | inst), lung)
 #' jstable:::coxExp(jstable:::coxmeTable(fit))
 #' @rdname coxExp
-#' @importFrom stats pnorm
+#' @importFrom stats pnorm qnorm
 
 coxExp <- function(cox.coef, dec) {
-  HR <- paste(round(exp(cox.coef[, 1]), dec), " (", round(exp(cox.coef[, 1] - 1.96 * cox.coef[, 2]), dec), ",", round(exp(cox.coef[, 1] + 1.96 * cox.coef[, 2]), dec), ")", sep = "")
+  HR <- paste(round(exp(cox.coef[, 1]), dec), " (", round(exp(cox.coef[, 1] - stats::qnorm(0.975) * cox.coef[, 2]), dec), ",", round(exp(cox.coef[, 1] + stats::qnorm(0.975) * cox.coef[, 2]), dec), ")", sep = "")
   pv <- cox.coef[, "p"]
   # pv = 2*(1-pnorm(abs(cox.coef[, "z"])))
   return(cbind(HR, pv))
